//
// Copyright Amazon.com Inc. or its affiliates.
// All Rights Reserved.
//
// SPDX-License-Identifier: Apache-2.0
//

extension LoggingCategory: CategoryConfigurable {

    /// Configures the LoggingCategory using the incoming CategoryConfiguration.
    func configure(using configuration: CategoryConfiguration?) throws {
        try concurrencyQueue.sync {
            let plugin: LoggingCategoryPlugin
            switch configurationState {
            case .default:
                // Default plugin is already assigned, and no configuration is applicable, exit early
                configurationState = .configured
                return
            case .pendingConfiguration(let pendingPlugin):
                plugin = pendingPlugin
            case .configured:
                let error = ConfigurationError.amplifyAlreadyConfigured(
                    "\(categoryType.displayName) has already been configured.",
                    "Remove the duplicate call to `Amplify.configure()`"
                )
                throw error
            }

            try plugin.configure(using: configuration?.plugins[plugin.key])
            self.plugin = plugin
            configurationState = .configured
        }
    }

    func configure(using amplifyConfiguration: AmplifyConfiguration) throws {
        try configure(using: categoryConfiguration(from: amplifyConfiguration))
    }

}
