//
//  Enumerator.h
//  MyDependency
//
//  Created by Brennan Stehling on 2/22/21.
//

#import <Foundation/Foundation.h>

#import "Task.h"
#import "UploadTask.h"
#import "DownloadTask.h"
#import "MultiPartUploadTask.h"

NS_ASSUME_NONNULL_BEGIN

typedef void (^VoidBlock) (void);
typedef void (^UploadCompletedBlock) (UploadTask * task, NSError * _Nullable error);
typedef void (^DownloadCompletedBlock) (DownloadTask * task, NSError * _Nullable error);

typedef void (^ProgressBlock) (Task *task, NSProgress *progress);

typedef void (^UploadCompletionHandlerBlock) (UploadTask *task, NSError * _Nullable error);

typedef void (^DownloadCompletionHandlerBlock) (DownloadTask *task,
                                                NSURL * _Nullable location,
                                                NSData * _Nullable data,
                                                NSError * _Nullable error);

typedef void (^MultiPartProgressBlock) (MultiPartUploadTask *task,
                                        NSProgress *progress);

typedef void (^MultiPartUploadCompletionHandlerBlock) (MultiPartUploadTask *task,
                                                       NSError * _Nullable error);

@interface Enumerator : NSObject

- (void)enumerateToAssignBlocksForUploadTask:(nullable void (^)(UploadTask *uploadTask,
                                                                _Nullable ProgressBlock * _Nullable uploadProgressHandler,
                                                                _Nullable UploadCompletedBlock * _Nullable completionBlock))uploadTaskBlock
                                downloadTask:(nullable void (^)(DownloadTask *downloadTask,
                                                                _Nullable ProgressBlock * _Nullable downloadProgressHandler,
                                                                _Nullable DownloadCompletedBlock * _Nullable completionBlock))downloadTaskBlock
                                                                NS_SWIFT_NAME(enumerateToAssignBlocks(uploadTask:downloadTask:));

//- (void)enumerateToAssignBlocksForUploadTask:(nullable void (^)(UploadTask *uploadTask,
//                                                                _Nullable ProgressBlock * _Nullable uploadProgressHandler,
//                                                                _Nullable UploadCompletionHandlerBlock * _Nullable completionHandlerReference))uploadBlocks
//                                downloadTask:(nullable void (^)(DownloadTask *downloadTask,
//                                                                _Nullable ProgressBlock * _Nullable downloadProgressHandler,
//                                                                _Nullable DownloadCompletionHandlerBlock * _Nullable completionHandlerReference))downloadBlocks NS_SWIFT_NAME(enumerateToAssignBlocks(uploadTask:downloadTask:));

//#if INCLUDE_SECOND_FUNCTION
//-(void)enumerateToAssignBlocksForUploadTask:(void (^)(UploadTask *uploadTask,
//                                                      ProgressBlock _Nullable * _Nullable uploadProgressHandler,
//                                                      UploadCompletionHandlerBlock _Nullable * _Nullable completionHandlerReference))uploadBlocks
//             multiPartUploadBlocksAssigner: (void (^) (MultiPartUploadTask *multiPartUploadTask,
//                                                       MultiPartProgressBlock _Nullable * _Nullable multiPartUploadProgressHandler,
//                                                       MultiPartUploadCompletionHandlerBlock _Nullable * _Nullable completionHandlerReference)) multiPartUploadBlocks
//                    downloadBlocksAssigner:(void (^)(DownloadTask *downloadTask,
//                                                     ProgressBlock _Nullable * _Nullable downloadProgressHandler,
//                                                     DownloadCompletionHandlerBlock _Nullable * _Nullable completionHandlerReference))downloadBlocks;
//
//#endif

@end

NS_ASSUME_NONNULL_END
